add: add

View source: R/mathml.R

addR Documentation

add

Description

This is a function that allows the user to highlight the mistakes, in particular an extra element in a list

Usage

add(expr)

Arguments

expr

expression

Value

expr , e.g., highlights a + b from a + b


mathml documentation built on May 22, 2026, 5:06 p.m.