grapes-less-than-equals-greater-than-grapes: If and only if condition, displayed as x <=> y

%<=>%R Documentation

If and only if condition, displayed as x <=> y

Description

If and only if condition, displayed as x <=> y

Usage

x %<=>% y

Arguments

x

first element

y

second element

Value

NA, it produces a double arrow double-sided


mathml documentation built on May 22, 2026, 5:06 p.m.