prod_over: product over a range. On the R side, this function just...

View source: R/mathml.R

prod_overR Documentation

product over a range. On the R side, this function just returns the product of the first argument, but allows for decorations.

Description

product over a range. On the R side, this function just returns the product of the first argument, but allows for decorations.

Usage

prod_over(x, from, to)

Arguments

x

the object to be multiplied

from

decoration for prod_from^to x_i

to

decoration for prod_from^to x_i

Value

The function returns prod(x)

See Also

prod(), sum_over()

Examples

mathjax(quote(prod_over(x[i], i=1L, N)))


mathml documentation built on June 8, 2025, 11:12 a.m.