| prod_over | R Documentation |
product over a range. On the R side, this function just returns the product of the first argument, but allows for decorations.
prod_over(x, from, to)
x |
the object to be multiplied |
from |
decoration for prod_from^to x_i |
to |
decoration for prod_from^to x_i |
The function returns prod(x)
prod(), sum_over()
mathjax(quote(prod_over(x[i], i=1L, N)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.